@@ -14,22 +14,22 @@ $LastChangedRevision$
 
 =item Release Version
 
-1.10.1
+1.10.3
 
 =cut
 
 # Set the Version Number.
 BEGIN {
-    our $VERSION = '1.10.2';
+    our $VERSION = '1.10.3';
 }
 
 =item Date
 
-$LastChangedDate: 2006-04-24 08:19:04 -0700 (Mon, 24 Apr 2006) $
+$LastChangedDate: 2006-06-23 04:56:33 +0200 (Fri, 23 Jun 2006) $
 
 =item Subversion ID
 
-$Id: Bric.pm 7237 2006-04-24 15:19:04Z paulo $
+$Id: Bric.pm 7605 2006-06-23 02:56:33Z theory $
 
 =back
 
