@@ -896,7 +896,7 @@ sub handle_upload {
     my $filename = $agent =~ /windows/i && $agent =~ /msie/i
         ? Bric::Util::Trans::FS->base_name($upload->filename, 'win32')
         : $upload->filename;
-    $media->upload_file($fh, $filename, $upload->type, $upload->size);
+    $media->upload_file($fh, $filename, undef, $upload->size);
     log_event('media_upload', $media);
     return $self;
 }
