@@ -13,6 +13,7 @@ use Bric::Biz::Asset::Template;
 use Bric::Biz::ElementType;
 use Bric::Biz::Workflow;
 use Bric::Biz::Workflow::Parts::Desk;
+use Bric::Config qw(ENCODE_OK);
 use Bric::Util::Priv::Parts::Const qw(:all);
 use Bric::Util::Burner;
 use Bric::Util::Fault qw(rethrow_exception);
@@ -237,15 +238,15 @@ sub notes : Callback {
 sub trail : Callback {
     my $self = shift;
     my $widget = $self->class_key;
-    
+
     my $action = $self->params->{$widget.'|trail_cb'};
-    
+
     # Save the metadata we've collected on this request.
     my $fa = get_state_data($widget, 'template');
     my $id = $fa->get_id;
-    
-    &$save_meta($self->params, $widget, $fa) if $action eq 'edit';
-    
+
+    $save_meta->($self, $widget, $fa) if $action eq 'edit';
+
     # Set a redirection to the code page to be enacted later.
     $self->set_redirect("/workflow/trail/template/$id");
 }
@@ -704,7 +705,8 @@ $handle_upload = sub {
     my $widget = $self->class_key;
     my $upload = $self->apache_req->upload("$widget|upload_file");
     my $fh = $upload->fh;
-    $fa->set_data(do { local $/; <$fh>});
+    binmode $fh, ':utf8' if ENCODE_OK;
+    $fa->set_data(do { local $/; <$fh> });
     return $self;
 };
 
