@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-15 12:46:46 -0700 (Thu, 15 Jun 2006) $
+$LastChangedDate: 2007-04-24 14:29:27 +0200 (Tue, 24 Apr 2007) $
 
 =head1 SYNOPSIS
 
@@ -53,6 +53,8 @@ use Bric::Util::Language;
 use Bric::Util::Fault qw(throw_gen);
 use Bric::App::Authz qw(:all);
 use Bric::Util::Priv::Parts::Const qw(:all);
+use URI;
+use URI::Escape;
 
 #==============================================================================#
 # Inheritance                          #
@@ -580,7 +582,7 @@ browser and to abort the request.
 
 B<Throws:> NONE.
 
-B<Side Effects:> Becuase C<redirect_onload()> executes immediately, if it is
+B<Side Effects:> Because C<redirect_onload()> executes immediately, if it is
 called from a callback, note that no further callbacks will be executed, not
 even post-callback request callbacks.
 
@@ -590,7 +592,14 @@ B<Notes:> NONE.
 
 sub redirect_onload {
     my $loc = shift or return;
-    my $js = qq{<script>location.href='$loc';</script>\n};
+
+    # escape the path+query part if necessary
+    my $uri = URI->new($loc);
+    my $pq = $uri->path_query;
+    $uri->path_query($pq);
+
+    my $js  = sprintf q{<script>location.href='%s';</script>\n},
+                      $uri;
 
     if (my $m = HTML::Mason::Request->instance) {
         # Use the Mason request object.
