@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-21 12:21:12 -0700 (Wed, 21 Jun 2006) $
+$LastChangedDate: 2007-02-27 20:33:13 +0100 (Tue, 27 Feb 2007) $
 
 =head1 SYNOPSIS
 
@@ -815,6 +815,7 @@ sub add_contributor {
 
     my $dirty = $self->_get__dirty();
     my $contribs = $self->_get_contributors() || {};
+    $role ||= 'DEFAULT';
 
     # get the contributor id
     my $c_id = ref $contrib ? $contrib->get_id() : $contrib;
@@ -2109,8 +2110,8 @@ sub checkout {
     $oc_coll->del_objs(@ocs);
     $oc_coll->add_new_objs(@ocs);
 
-    $self->_set([qw(user__id modifier version_id checked_out)] =>
-                [$param->{user__id}, $param->{user__id}, undef, 1]);
+    $self->_set([qw(user__id modifier version_id checked_out note)] =>
+                [$param->{user__id}, $param->{user__id}, undef, 1, undef]);
     $self->_set(['_update_contributors'] => [1]) if $contribs;
 }
 
@@ -2507,7 +2508,7 @@ sub _construct_uri {
     my ($slug, $slash) = $self->key_name eq 'story' ? ($self->get_slug, '/')
                                                     : ('', '')
                                                     ;
-
+    $slug = '' unless defined $slug;
     $fmt =~ s{/%{categories}/?}{$category_uri}g;
     $fmt =~ s/%{slug}/$slug/g;
     unless ($fmt =~ s/%{uuid}/$self->get_uuid/ge) {
