@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-15 12:46:46 -0700 (Thu, 15 Jun 2006) $
+$LastChangedDate: 2007-03-27 12:46:12 +0200 (Tue, 27 Mar 2007) $
 
 =head1 SYNOPSIS
 
@@ -93,7 +93,7 @@ $LastChangedDate: 2006-06-15 12:46:46 -0700 (Thu, 15 Jun 2006) $
  # Access Categories
  $cat             = $biz->get_primary_category;
  $biz             = $biz->set_primary_category($cat);
- ($cats || @cats) = $biz->get_secondary_categories;
+ ($cats || @cats) = $biz->get_secondary_categories($sortby);
  $biz             = $biz->add_categories([$category, ...])
  ($cats || @cats) = $biz->get_categories()
  $biz             = $biz->delete_categories([$category, ...]);
@@ -1486,9 +1486,21 @@ sub set_primary_category {
 
 ################################################################################
 
-=item (@cats || $cats) = $story->get_secondary_categories()
+=item (@cats || $cats) = $story->get_secondary_categories( $sortby )
+
+Returns the non-primary categories that are associated with this story. Takes 
+an optional sort by field.
+
+Supported Keys:
+
+=over 4
+
+=item *
+
+uri - Sort in alphabetically ascending uri order.
+
+=back 
 
-Returns the non-primary categories that are associated with this story
 
 B<Throws:>
 
@@ -1505,7 +1517,7 @@ NONE
 =cut
 
 sub get_secondary_categories {
-    my ($self) = @_;
+    my ($self,$sort) = @_;
     my $cats = $self->_get_categories();
     my @seconds;
     my $reset;
@@ -1528,6 +1540,13 @@ sub get_secondary_categories {
         $self->_set({ '_categories' => $cats });
         $self->_set__dirty($dirty);
     }
+	if (($sort) && ($sort eq 'uri')) {
+	    @seconds =
+	      map  { $_->[1]                  }
+		  sort { $a->[0] cmp $b->[0]      }
+	      map  { [ lc $_->get_uri => $_ ] }
+		  @seconds; 
+	};
     return wantarray ? @seconds : \@seconds;
 }
 
@@ -1552,17 +1571,15 @@ sub add_categories {
     my @grp_ids = $self->get_grp_ids();
     my $check = 0;
     foreach my $c (@$categories) {
-        # get the id
         my $cat_id = ref $c ? $c->get_id() : $c;
-        my $asset_grp_id = ref $c ? $c->get_asset_grp_id()
-          : Bric::Biz::Category->lookup({ id => $c })->get_asset_grp_id;
         # if it already is associated make sure it is not going to be deleted
         if (exists $cats->{$cat_id}) {
             $cats->{$cat_id}->{'action'} = undef;
         } else {
+            $c = Bric::Biz::Category->lookup({ id => $c }) unless ref $c;
             $cats->{$cat_id}->{'action'} = 'insert';
-            $cats->{$cat_id}->{'object'} = ref $c ? $c : undef;
-            push @grp_ids, $asset_grp_id;
+            $cats->{$cat_id}->{'object'} = $c;
+            push @grp_ids, $c->get_asset_grp_id();
             $check = 1;
         }
     }
