@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-14 11:40:21 -0700 (Wed, 14 Jun 2006) $
+$LastChangedDate: 2006-06-14 20:40:21 +0200 (Wed, 14 Jun 2006) $
 
 =head1 SYNOPSIS
 
