@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-09-23 15:52:57 -0700 (Fri, 23 Sep 2005) $
+$LastChangedDate: 2006-08-07 22:45:13 +0200 (Mon, 07 Aug 2006) $
 
 =head1 DESCRIPTION
 
@@ -26,6 +26,7 @@ instead.
 =cut
 
 use base 'Bric::Biz::ElementType';
+use Bric::Biz::AssetType::Parts::Data;
 
 1;
 __END__
