@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-09-23 15:52:57 -0700 (Fri, 23 Sep 2005) $
+$LastChangedDate: 2005-09-24 00:52:57 +0200 (Sat, 24 Sep 2005) $
 
 =head1 DESCRIPTION
 
