@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-03-14 15:45:41 -0800 (Tue, 14 Mar 2006) $
+$LastChangedDate: 2006-03-15 00:45:41 +0100 (Wed, 15 Mar 2006) $
 
 =head1 SYNOPSIS
 
