@@ -19,7 +19,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-13 20:25:10 -0700 (Tue, 13 Jun 2006) $
+$LastChangedDate: 2006-06-14 05:25:10 +0200 (Wed, 14 Jun 2006) $
 
 =head1 SYNOPSIS
 
