@@ -19,7 +19,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =item Date
 
-$LastChangedDate: 2006-06-16 15:51:26 -0700 (Fri, 16 Jun 2006) $
+$LastChangedDate: 2006-06-17 00:51:26 +0200 (Sat, 17 Jun 2006) $
 
 =item Subversion ID
 
