@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-10-12 12:48:33 -0700 (Wed, 12 Oct 2005) $
+$LastChangedDate: 2005-10-12 21:48:33 +0200 (Wed, 12 Oct 2005) $
 
 
 =head1 SYNOPSIS
