@@ -11,7 +11,7 @@ $LastChangedRevision$
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-20 12:23:37 -0700 (Tue, 20 Jun 2006) $
+$LastChangedDate: 2006-06-20 21:23:37 +0200 (Tue, 20 Jun 2006) $
 
 =head1 SYNOPSIS
 
