@@ -19,7 +19,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =item Date
 
-$LastChangedDate: 2006-03-15 03:28:37 -0800 (Wed, 15 Mar 2006) $
+$LastChangedDate: 2006-03-15 12:28:37 +0100 (Wed, 15 Mar 2006) $
 
 =item Subversion ID
 
