@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-15 12:46:46 -0700 (Thu, 15 Jun 2006) $
+$LastChangedDate: 2006-08-09 06:57:25 +0200 (Wed, 09 Aug 2006) $
 
 =head1 SYNOPSIS
 
@@ -1870,12 +1870,16 @@ $get_em = sub {
             # database with the index-defeating query
             # "WHERE outut_channel__id = NULL"
             return ($href ? {} : []) unless defined $v;
-            $tables .= ', job__resource jrr, job__server_type jst, '
-                     . 'server_type__output_channel stoc';
-            $wheres .= ' AND r.id = jrr.resource__id '
-                     . 'AND jrr.job__id = jst.job__id '
-                     . 'AND jst.server_type__id = stoc.server_type__id AND '
-                     . any_where $v, 'stoc.output_channel__id = ?', \@params;
+            $wheres .= ' AND r.id IN (
+                    SELECT jrr.resource__id
+                    FROM   job__resource jrr,
+                           job__server_type jst,
+                           server_type__output_channel stoc
+                    WHERE  jrr.job__id = jst.job__id
+                           AND jst.server_type__id = stoc.server_type__id
+                           AND jrr.resource__id = r.id AND '
+                . any_where($v, 'stoc.output_channel__id = ?', \@params)
+                . ')';
         } elsif ($k eq 'is_dir') {
             # Check for directories or not.
             $wheres .= " AND r.$k = ?";
