@@ -34,7 +34,7 @@ $LastChangedRevision$
 
 =head1 DATE
 
-$LastChangedDate: 2006-03-15 03:37:12 -0800 (Wed, 15 Mar 2006) $
+$LastChangedDate: 2006-03-15 12:37:12 +0100 (Wed, 15 Mar 2006) $
 
 =head1 SYNOPSIS
 
