@@ -34,7 +34,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-14 12:23:31 -0700 (Wed, 14 Jun 2006) $
+$LastChangedDate: 2006-08-03 00:48:04 +0200 (Thu, 03 Aug 2006) $
 
 =head1 SYNOPSIS
 
@@ -342,7 +342,7 @@ sub delete {
                 if DEBUG;
 
         # lookup category
-        my $category = Bric::Biz::Category->lookup({ id => $category_id, site_id => $args->{site_id} });
+        my $category = Bric::Biz::Category->lookup({ id => $category_id });
         throw_ap(error => __PACKAGE__
                    . "::delete : no category found for id \"$category_id\"")
           unless $category;
