@@ -35,7 +35,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-03-11 06:15:13 -0800 (Sat, 11 Mar 2006) $
+$LastChangedDate: 2006-03-11 15:15:13 +0100 (Sat, 11 Mar 2006) $
 
 =head1 SYNOPSIS
 
