@@ -56,7 +56,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-01-17 16:09:49 -0800 (Tue, 17 Jan 2006) $
+$LastChangedDate: 2006-01-18 01:09:49 +0100 (Wed, 18 Jan 2006) $
 
 =head1 SYNOPSIS
 
