@@ -61,7 +61,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
+$LastChangedDate: 2006-03-18 01:26:34 +0100 (Sat, 18 Mar 2006) $
 
 =head1 SYNOPSIS
 
