@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-15 12:46:46 -0700 (Thu, 15 Jun 2006) $
+$LastChangedDate: 2006-06-15 21:46:46 +0200 (Thu, 15 Jun 2006) $
 
 =head1 SYNOPSIS
 
