@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-03-31 14:45:45 -0800 (Fri, 31 Mar 2006) $
+$LastChangedDate: 2007-08-09 10:44:19 +0200 (Thu, 09 Aug 2007) $
 
 =head1 SYNOPSIS
 
@@ -238,7 +238,7 @@ sub new {
     my ($self, $init) = @_;
     $self = bless {}, $self unless ref $self;
     $init->{_active} = exists $init->{active} ? 0 : 1;
-    $init->{permanent} = exists $init->{permanent} ? 1 : 0;
+    $init->{permanent} = exists $init->{permanent} && $init->{permanent} ? 1 : 0;
     push @{$init->{grp_ids}}, INSTANCE_GROUP_ID;
     $init->{secret} = ! exists $init->{secret} ? $self->get_secret :
       $init->{secret} ? 1 : 0;
