@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-01-23 15:34:28 -0800 (Mon, 23 Jan 2006) $
+$LastChangedDate: 2006-01-24 00:34:28 +0100 (Tue, 24 Jan 2006) $
 
 =head1 SYNOPSIS
 
