@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2004-11-19 00:55:15 -0800 (Fri, 19 Nov 2004) $
+$LastChangedDate: 2004-11-19 09:55:15 +0100 (Fri, 19 Nov 2004) $
 
 =head1 SYNOPSIS
 
